#! /usr/bin/env python3

import os

from topsim import TopSim

datafile = os.path.join(os.path.split(__file__)[0], "emoji.tsv")

data = [line.strip().split('\t') for line in open(datafile)]
emojimap = dict(data)
datamap = {i: (emoji, text) for i, (emoji, text) in enumerate(data)}

ts = TopSim((text for emoji, text in data), numGrams=3)

def search(query, k=1):
    return [
        (
            sim,
            [datamap[ln] for ln in lns]
        )
        for sim, lns in ts.search(emojimap.get(query, query), k=k, simFunc="tversky")
    ]



#! /usr/bin/env python3

from setuptools import setup

url = "https://github.com/chuanconggao/TopEmoji"
version = "0.1.2"

setup(
    name="TopEmoji",

    packages=["topemoji"],
    scripts=["topemoji-cli"],
    include_package_data=True,

    url=url,

    version=version,
    download_url=f"{url}/tarball/{version}",

    license="MIT",

    author="Chuancong Gao",
    author_email="chuancong@gmail.com",

    description="🔎 the most similar 😀s.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",

    keywords=[
        "similarity-search",
        "string-search",
        "emoji"
    ],
    classifiers=[
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3"
    ],

    python_requires=">= 3",
    install_requires=[
        line.strip() for line in open("requirements.txt")
    ]
)
